from plone.theme.interfaces import IDefaultPloneLayer

class IAlgolTheme(IDefaultPloneLayer):
    """Marker interface that defines a Zope 3 browser layer.
    """
    """Marker interface that defines a ZSubject.
       It will be used for the viewlets that we want to add to the
       "My Theme" skin only.
    """
